#
# spec file for package blktests
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           blktests
Version:        0+20250415.9aa2023
Release:        1.1
Summary:        Linux kernel block layer testing framework
License:        GPL-2.0-or-later
URL:            https://github.com/osandov/blktests
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
Requires:       fio
Requires:       gawk
Requires:       gcc
Requires:       make
Recommends:     blktrace
Recommends:     device-mapper
Recommends:     e2fsprogs
Recommends:     multipath-tools
Recommends:     nvme-cli
Recommends:     xfsprogs

%description
blktests is a test framework for the Linux kernel block layer and
storage stack. It is inspired by the xfstests filesystem testing
framework.

%prep
%autosetup

%build
%make_build

%install
%make_install prefix="%{_prefix}/lib"

%files
%doc README.md
%license LICENSES/GPL-2.0 LICENSES/GPL-3.0
%{_prefix}/lib/blktests

%changelog
* Wed Apr 23 2025 sebastian.chlad@suse.com
- Update to version 0+20250415.9aa2023:
  * nvme: add testcase for secure concatenation
  * nvme: add testcase for TLS-encrypted connections
  * common/nvme: handle option '--concat' for _nvme_connect_subsys
  * common/nvme: TLS target support
  * common/nvme: add '--tls' argument to _nvme_connect_subsys()
  * nvme/rc: introduce _have_libnvme_ver()
  * nvme/rc: introduce _have_tlshd_ver() and _have_systemd_tlshd_service()
  * common/rc,fio: factor out _compare_three_version_numbers()
  * common/rc: introduce _systemctl_start() and _systemctl_stop()
  * common/rc: introduce _have_systemctl_unit()
  * nvme/061: add test teardown and setup fabrics target during I/O
  * nvme/060: add test nvme fabrics target resetting during I/O
  * common/nvme: move nvmf_wait_for_state to common code
  * common/nvme: add debug nvmet path variable
  * nvme/025: use character device for nvme effects-log command
  * src/Makefile: include CFLAGS in probe macros
  * zbd/012: avoid fio stop by I/O scheduler set failure
  * common/nvme: use correct local wwnn/wwpn for rport removal
  * tests/throtl: add a new test 006
  * common/xfs: verify xfs_io supports statx atomic write attributes
  * common/xfs: add _test_dev_suits_xfs() to verify logical block size will work
  * tests: use test device min io to support bs > ps
  * common/xfs: use min io for fs blocksize
  * common: add and use min io for fio
  * block/032: make error messages clearer if mkfs or mount fails
  * common/xfs: ignore first umount error on _xfs_mkfs_and_mount()
  * nvme/059: add atomic write tests
  * scsi/009: add atomic write tests
  * srp: skip test if scsi_transport_srp module is loaded and in use
  * nvme/056: Add check for empty ddp capabilities
  * nvme/058: detach loop device after test finish
  * nvme/053: do not use awk
  * tests: Remove unnecessary '&&' in requires() functions
  * throtl: fix the race between submitting IO and setting cgroup.procs
  * throtl/002: calculate block-size based on device max-sectors setting
  * common/rc: test _have_driver before checking driver parameter
  * tests/rnbd: Implement RNBD regression test
  * tests/rnbd: Add a basic RNBD test
  * zbd/012: Test higher queue depths
  * common/ublk: update io_uring setting during the tests
  * block/035: use the common functions _io_uring_enable/_io_uring_restore
  * common/rc: introduce _io_uring_enable/_io_uring_restore
  * blktests: src/miniublk.c: fix segment fault when io_uring is disabled
  * nvme/049: update fio_output msg check for io_uring_cmd support
  * throtl/{002,003}: update max_sectors setting
  * blktests: src/miniublk.c: fix unaligned mmap offset for 64K page size
  * nvme: add test for rapid namespace remapping
  * nvme: add test for basic ANA support
  * nvme: delete all ana_groups when removing a port
  * nvme: add argument '--ports' to _nvmet_target_setup()
  * nvme: add _setup_nvmet_ns_ana()
  * nvme: add _setup_nvmet_port_ana()
  * zbd/012: Test requeuing of zoned writes and queue freezing
  * nvme/056: add test for nvme-tcp zero-copy offload
  * contrib: add remote target setup/cleanup script
  * nvme/030: only run against kernel soft target
  * common/nvme: add digest options to __nvme_connect_subsys()
  * nvme/rc: introduce remote target support
  * nvme/{041-045,051,055}: double-quote def_* variable references
  * nvme: add test for writing to file-ns just after disabling it
  * nvme/052: move nvmf_wait_for_ns() to common/nvme
  * block/035: enable io_uring if it is disabled
  * nvme/029: capture all the FULL log from test_user_io
  * nvme/039: check for logical block size of test device
  * nvme: delete all namespaces in _remove_nvmet_subsystem()
  * throtl: set "io" to subtree_control only if required
  * nvme: drop arguments from _create_nvmet_port()
  * nvme: rework fcloop
  * nvme/052: do not create namespace when setting up the target
  * nvme/017: do not create namespace when setting up the target
  * nvme/016: do not create namespace when setting up the target
  * nvme: move _nvmet_target_setup() to common/nvme
  * nvme/rc: Implement --blkdev none for _nvmet_target_setup()
  * tests/throtl: add a new test 005
  * tests/throtl: add a new test 004
  * tests/throtl: add a new test 003
  * tests/throtl: add a new test 002
  * tests/throtl: add first test for blk-throttle
  * common/nvme, nvme/{016,017,051,052}: introduce def_nsid
  * nvme, md/001: support only long options for _create_nvmet_subsystem()
  * common/nvme, nvme/{016,017,052}: improve _create_nvmet_ns()
  * common/nvme, nvme/003: specify "--port none" to _nvme_connect_subsys()
  * nvme: pass in port parameter to _nvme_connect_subsys()
  * nvme: check for controller device in _nvme_connect_subsys()
  * nvme: simplify _get_nvmet_ports()
  * nvme: return error from _find_nvme_ns()
  * nvme: fix fc port clean up failure
  * nvme/{rc,002,016,017,030}: pass port ID to genctr helper functions
  * nvme: introduce wwnn/wwpn helper functions
  * nvme: sanitize transport parameter in _create_nvmet_port()
  * nvme, md/001: make trtype argument to _create_nvmet_port() optional
  * nvme/038: use nvme_trtype instead of hardcoding
  * common/rc: Uniform the style of skip reasons
  * block/027: setup scsi_debug with MQ
  * nvme: test the nvme reservation feature
  * nvme/{rc,002,016,017,030,052}, md/001: introduce --resv_enable argument
  * common/multipath-over-rdma: remove dir /tmp/fio-state-files
  * common/fio: dont save the fio verify.state file
  * block/031: remove the fio verify.state file
  * nvme/{033-037}: timeout while waiting for nvme passthru namespace device
  * nvme/052: wait for namespace removal before recreating namespace
  * nvme: add test for controller rescan under I/O load
  * nvme/032: skip on non-PCI devices
  * nvme/{033-037,039}: skip passthru tests on multipath devices
  * zbd/011: add test for DM resource limits stacking
  * loop/011: skip if running on kernel older than v6.9.11
  * dm/002: add --retry option to dmsetup remove command
  * md: add regression test for "md/md-bitmap: fix writing non bitmap pages"
  * nvme: move helper functions to common/nvme
  * nbd/rc: check nbd-server port readiness in _start_nbd_server()
  * loop/010: skip when kernel is older than v6.11
  * loop/010: do not assume /dev/loop0
  * dm/002: do not assume 512 byte block size
  * nvme: add test for creating/deleting file-ns
  * loop: Add regression test for unsupported backing file fallocate
  * nbd/004: drop the check for "couldn't allocate config" message
  * check: confirm dependent commands
  * block/038: support built-in null_blk
  * block: add regression test for null-blk concurrently power/submit_queues test
  * nvme: add regression test for concurrently enable/disable nvmet ns
  * loop: Detect a race condition between loop detach and open
  * README: add dependent command descriptions
  * blktests: fix how we handle waiting for nbd to connect
  * tests/dm: add dm-dust general functionality test
  * nvme/rc,srp/rc,common/multipath-over-rdma: rename use_rxe to USE_RXE
  * nvme/{rc,016,017}: rename nvme_num_iter to NVME_NUM_ITER
  * nvme/{rc,010,017,031,034,035}: rename nvme_img_size to NVME_IMG_SIZE
  * nvme/{021,022,025,026,027,028}: do not hard code target blkdev type
  * nvme/{007,009,011,013,015,020,024}: drop duplicate nvmet blkdev type tests
  * nvme/{006,008,010,012,014,019,023}: support NVMET_BLKDEV_TYPES
  * nvme/{002-031,033-038,040-045,047,048}: support NMVET_TRTYPES
  * nvme/rc: introduce NVMET_BLKDEV_TYPES
  * nvme/rc: add blkdev type environment variable
  * nvme/rc: introduce NVMET_TRTYPES
  * common/rc: introduce _check_conflict_and_set_default()
  * meta/{018,019}: add test cases to check _set_combined_conditions
  * common/rc: introduce _set_combined_conditions
  * meta/{016,017}: add test cases to check repeated test case runs
  * check: use set_conditions() for the CAN_BE_ZONED test cases
  * check: support test case repeat by different conditions
  * check: factor out _run_test()
  * nvme/039: adjust to util-linux v2.40 dmesg format change
  * nbd/002: repeat partition existence check for ioctl interface
  * nbd/002: fix wrong -L/-nonetlink option usage
  * block/033: additional fix
  * block/034: add the missing +x mode
  * nvme/{003,006,007}: remove the blank line
  * block/033: fix the output when ublk prog not avaiable
  * block/037: add test to cover blk-cgroup vs. disk rebind
  * block/036: test return EIO from BLKRRPART
  * block/035: Report IOPS
  * block/035: Test shared queue fairness
  * scsi/008: Test SCSI disk data lifetime support
  * common/fio: Fix the _run_fio() return code
  * nvme/rc: fix shellcheck warning SC2086
  * nvme/{013,014}: fix device filename
  * nvme/011: fix filename path
  * nvme/028: drop unused nvmedev
  * nvme: don't assume namespace id
  * nvme/{041,042,043,044,045,048}: do not pass default host{nqn|id} to _nvme_connect_subsys
  * nvme: drop default subsysnqn argument from _nvmet_passthru_target_connect
  * nvme: drop default subsysnqn argument from _nvme_passthru_target_{setup|cleanup}
  * nvme: drop default subsysnqn argument from _nvme_{connect|disconnect}_subsys
  * nvme: drop default trtype argument for _nvmet_passthru_target_connect
  * nvme: drop default trtype argument for _nvmet_connect_subsys
  * nvme/031: do not open code target setup/cleanup
  * nvme/rc: do not cleanup external managed loop device
  * nvme/rc: remove unused connect options
  * nvme/rc: add nqn/uuid args to target setup/cleanup helper
  * nvme/rc: connect subsys only support long options
  * nvme/{014,015,018,019,020,023,024,026,045,046}: use long command line option for nvme
  * nvme/rc: use long command line option for nvme
  * nvme/{012,013,035}: check return value of _xfs_run_fio_verify_io
  * common/xfs: propagate errors from _xfs_run_fio_verify_io
  * nvme/rc: log error if stale configuration is found
  * nvme/rc: silence fcloop cleanup failures
  * nvme/rc: silence error on module unload for fc
  * nvme/048: make queue count check retry-able
  * nvme/048: remove unused argument for set_qid_max
  * nbd/001: wait for the device node to show up before running parted
  * nvme: Add passthru error logging tests to nvme/039
  * nvme/029: reserve hugepages for lager allocations
  * nbd/001: change to use lsblk raw output format
* Fri Feb 16 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 0+20240213.ac3d8d0:
  * nvme/rc: revert nvme-cli context tracking
  * nvme/rc: do not issue errors when disconnecting when using fc transport
  * nvme/rc: do not issue warnings on cleanup when using fc transport
  * nvme/rc: filter out errors from cat when reading files
  * nvme/029: fix local variable declarations
  * nvme/046: change nvme io-passthru command option from -o to --opcode
  * nvme: add nvme pci timeout testcase
  * block/031: allow to run with built-in null_blk driver
  * common/null_blk: introduce _have_null_blk_feature
  * nvme/rc: don't print the nvme connect msg
  * block/007: skip hybrid polling tests when kernel does not support it
  * block/011: set default timeout to 20 minutes
  * block/011: recover test target devices to online or live status
  * loop/009: require --option of udevadm control command
  * nvme/{041,042,043,044,045}: check dhchap_ctrl_secret support by nvme-fabrics
  * nvme: do not print subsystem NQN to stdout
  * nvme: do not print UUID to log files
  * common/ublk: allow to run ublk test without building miniublk
  * ublk/rc: prefer to rublk over miniublk
  * Fix common misspellings from codespell project
  * tests/srp: remove the unused file 015.out
  * src/miniublk: fix logical block size setting
  * block/002: fix TMPDIR path
  * nvme/{rc,017,031}: replace def_file_path with _nvme_def_file_path()
  * nvme/rc: fix rdma driver check
- Small spec file modernisation
* Wed Oct 11 2023 pcervinka@suse.com
- Replace disabled mode in service file by manual mode
- Update to version 0+20231006.1aeff01:
  * nbd/004: avoid left connection
  * Change the default RDMA driver from rdma_rxe to siw
  * srp/015: Remove this test
  * tests/srp/rc: Reduce the number of channels
  * tests/srp/rc: Rework use_blk_mq()
  * tests/nvme/031: fix connecting faiure
  * block/002,scsi/007,zbd/003: remove options for shellcheck SC2119
  * nvme: introduce nvmet_target_{setup/cleanup} common code
  * nvme/{033,034,035,036,37}: drop port handle between passthru target setup and cleanup
  * nvme/{033,034,035,036}: use default subsysnqn variable directly
  * Revert "Do not suppress any shellcheck warnings"
  * nvme: remove "udevadm settle" after _nvme_connect_subsys
  * nvme/rc: fix nvme device readiness check after _nvme_connect_subsys
  * nvme: Add explicitly host to allow_host list
  * nvme/rc: Add helper for adding/removing to allow list
  * nvme: Use def_subsys_uuid variable
  * nvme/rc: Add common def_subsys_uuid define
  * nvme: Use def_file_path variable instead local variable
  * nvme/rc: Add common file_path name define
  * nvme/{041,042,043,044,045,048}: Remove local variable hostnqn and hostid
  * nvme: Use def_subsysnqn variable instead local variable
  * nvme/rc: Add common subsystem nqn define
  * nvme/043: Use hostnqn to generate DHCAP key
  * nvme: Reorganize test preamble code section
  * nvme/{003,004,005,013,046,049}: Group all variables declarations
  * block/004: reset zones of TEST_DEV before fio operation
  * README: clarify motivations to add new test cases
  * CONTRIBUTING, README: recommend patch post for contributions
  * README: describe what './new' script documents
  * new: don't mandate double square brackets
  * src/Makefile: fix static linking of miniublk
  * common/scsi_debug: Use _unload_module() instead of modprobe -r
  * _unload_module(): Report the failure reason once
  * block/005: require queue/scheduler sysfs attribute
  * block/004, zbd/{005,006}: call _test_dev_set_scheduler
  * common/rc: introduce _require_test_dev_sysfs
  * common/{rc,dm}: introduce functions to set scheduler of dm destinations
  * common/dm: add script file for device-mapper functions
  * check, common/rc: save sysfs attribute path
  * common/ublk: avoid modprobe failure for built-in ublk_drv
  * nvme/{041,042,043,044,045,048}: Use default hostnqn and hostid
  * nvme/rc: Avoid triggering host nvme-cli autoconnect
  * nvme/048: Check for queue count check directly
  * nvme/043: use a valid hostkey
  * zbd/009: skip have_good_mkfs_btrfs when mkfs.btrfs not avaiable
  * nvme/rc: specify hostnqn and hostid to nvme discover and connect
* Tue Jun 27 2023 petr@cervinka.net
- Update to version 0+20230615.154e652:
  * block/034: Test memory is released by null-blk driver with memory_backed=1
  * nvme/040: Free loop back resources
  * block/011: recover test target NVME device capacity
  * block/011: skip when mounted block devices are affected
  * common/rc: introduce _get_pci_from_dev_sysfs
  * nvmeof-mp: Remove nvmeof-mp tests
  * nvme/rc: remove _filter_discovery
  * nvme/{016,017}: use _check_genctr instead of _filter_discovery
  * nvme/rc: Cleanup fc resource before module unloading
  * nvme/rc: Cleanup fc ports in reverse order
  * tests: Add ublk tests
  * src/miniublk: add user recovery
  * srp/rc: Replace _have_module() with _have_driver()
  * nvme/{016,017}: Make the number iterations configurable
  * nvme/{002,030}: Move discovery generation counter code to rc
  * nvme/{045,047}: Calculate IO size for random fio jobs
  * nvme: Add minimal test image size requirement
  * nvme: Make test image size configurable
  * Documentation: Add info on nvme_trtype
  * nvme/{032,040}: Use runtime fio background jobs
  * common/xfs: Limit fio size job to fit into xfs fs
  * common/xfs: Make size argument optional for _xfs_run_fio_verify_io
  * nvme/{014/015}: Do not hard code device size for dd test
  * nvme/rc: Auto convert test device size info
  * block/{001,002,027}: allow to run with built-in scsi_debug and sd_mod
  * scsi/{004,005}: allow to run with built-in scsi_debug
  * common/scsi_debug: introduce _configure_scsi_debug
  * common/scsi_debug: factor out _setup_scsi_debug_vars
  * common/scsi_debug, tests/*: re-define _have_scsi_debug
  * common/rc: skip module file check if modules path does not exist
  * loop/009: add test for loop partition uvents
  * test/nvme: add missing _have_fio check for nvme/045
  * tests/dm: add dm test group and a test for self-map
  * common/rc: fix kernel version parse failure
  * block/{014,015,030}: don't require modular null_blk for fault-injection
  * src/Makefile: forward LDFLAGS to $(CC)
  * nvme/039: avoid failure by error message rate limit
  * nvme/049: add test for uring-passthrough
  * common,fio: helper for version check
  * nvme/048: test queue count changes on reconnect
  * nvme/rc: Add timeout argument parsing to _nvme_connect_subsys()
  * nvme/047: Test different queue types for fabrics transports
  * nvme/rc: Add parametric transport required check
  * nvme/rc: Add nr queue parser arguments to _nvme_connect_subsys()
  * nvme/rc: Parse optional arguments in _nvme_connect_subsys()
  * tests/block/013.out: remove the unused 013.out file
  * tests: add the missing +x mode
* Sun Apr  2 2023 bjorn.lie@gmail.com
- Update to version 0+20230302.676d42c:
  * src/Makefile: fix number sign handling in macro
  * block/033: add test to cover gendisk leak
  * src: add mini ublk source code
  * nvme/046: add test for unprivileged passthrough
  * check, common/rc: support normal user privilege
  * block/032: add test to cover umount one deleted disk
  * Update tests for discovery log page changes
  * tests/block/007: Rework I/O polling
- Use explicit commit id. Also exclude .gitignore files.
* Wed Dec  2 2020 pcervinka@suse.com
- Update to version 0+20201022.e10add0:
  * nvme/038: Test removal of un-enabled subsystem and ports
  * nvme/037: Add test which loops passthru connect and disconnect
  * nvme/036: Add test for testing reset command on nvme-passthru
  * nvme/035: Add test to verify passthru controller with a filesystem
  * nvme/034: Add test for passthru data verification
  * nvme/033: Simple test to create and connect to a passthru target
  * nvme: Add common helpers for passthru tests
  * nvme: Search for specific subsysnqn in _find_nvme_loop_dev
  * common/xfs: Create common helper to verify block device with xfs
  * common/xfs: Create common helper to check for XFS support
  * common/fio: Remove state file in common helper
  * zbd/003: Reset zones when the test device has max_active_zones limit
  * block/004: Provide max_active_zones to fio command
  * common/rc: Add _test_dev_max_active_zones() helper function
  * nvme: support rdma transport type
  * common: move module_unload to common
  * nvme: support nvme-tcp when runinng tests
  * tests/nvme: restrict tests to specific transports
  * nvme: make tests transport type agnostic
  * nvme: consolidate some nvme-cli utility functions
  * nvme: consolidate nvme requirements based on transport type
  * nvme/005: add the missing _have_program nvme
  * common/multipath-over-rdma: make block scheduler directory optional
  * zbd/002: Check write pointers only when zones have valid conditions
  * zbd/005: Enable zonemode=zbd when zone capacity is less than zone size
  * zbd/004: Check zone boundary writes using zones without zone capacity gap
  * zbd/002: Check validity of zone capacity
  * zbd/rc: Support zone capacity report by blkzone
  * Remove partition rereading tests for reverted fixes
  * tests/srp/rc: Separate login parameters with a comma
  * srp tests: Use _{init,exit}_scsi_debug() instead of duplicating these functions
  * common/multipath-over-rdma: Log mkfs output
  * srp, nvmeof-mp: Use no_path_retry instead of queue_if_no_path
  * tests/nvmeof-mp/rc: Make login failures easier to debug
  * block/012: add comment explaning second --setro
  * tests/srp/rc: Fix a shellcheck warning
  * tests: mark tests with CAN_BE_ZONED=1
  * common/cpuhotplug: fix ALL_CPUS
  * tests/srp/rc: Do not pass an empty string to dd
  * zbd/007: Add --force option to blkzone reset
  * Fix ./check: line 275: LAST_TEST_RUN["$key"]: unbound variable
  * Fix unquoted integer shellcheck errors
  * travis: update shellcheck URL
  * tests/srp/rc: Make the SRP tests pass against kernel v5.7
* Fri May  1 2020 Petr Cervinka <pcervinka@suse.com>
- Update to version 0+20200430.bff70b0:
  * Add $DESCRIPTION to the TEST_RUN
  * Fix unintentional skipping of tests
  * Add a test that triggers the blk_mq_realloc_hw_ctxs() error path
  * Introduce the function _configure_null_blk()
  * Use _{init,exit}_null_blk instead of open-coding these functions
  * Make _exit_null_blk remove all null_blk device instances
  * common/fio: do not use norandommap with verify
* Thu Apr  2 2020 Sebastian Chlad <sebastian.chlad@suse.com>
- Add blktrace to recommended as some tests require it
* Wed Mar 25 2020 pcervinka@suse.com
- Update to version 20200307.cd11d00:
  * Support skipping tests from test{,_device}()
  * Show last run for skipped tests
  * Skip tests based on SKIP_REASON, not return value
  * nbd/003: fix compiling error with gcc version 4.8.5
  * nbd/003:add mount and clear_sock test for nbd
  * nvme/018: Reword misleading error message
  * nvme/018: Ignore message generated by nvme read
  * tests/srp/015: Add a test that uses the SoftiWARP (siw) driver
  * common/multipath-over-rdma, tests/srp: Make it easy to use siw instead of rdma_rxe
  * common/multipath-over-rdma: Rename two functions
- Apply spec-cleaner
- Change version format in service file
- Add GPL-3.0 to license list
- Add README.md to doc section
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Nov 25 2018 Jan Engelhardt <jengelh@inai.de>
- Move /var/lib/blktests to /usr/lib/blktests, packages don't
  deliver variadic data.
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- Fix package dependencies: nvmetcli is not needed, some packages
  can be missing (changed to Recommended:)
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- fix the %%files section: change %%{_sharedstatedir} to %%{_localstatedir}/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- change %%{_sharedstatedir} to %%{_localstatedir}/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- Correct the package category, System/Benchmarks is wrong
-> System/Benchmark
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
  Move the installed files from /usr/share to /var/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
  move the installed files from /usr/local to /usr/share
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- clean the .spec
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- fix the group of the package
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- Add the blktests.spec file
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
  Add new package for "blktests", the linux block layer testing framework
  from https://github.com/osandov/blktests
-
